#########################

use Test::More "no_plan";

#########################

use Money::Chinese;

my $object = Money::Chinese->new;

is($object->convert('111103'), '壹拾壹万壹仟壹佰零叁元整', '111103 is 壹拾壹万壹仟壹佰零叁元整');
is($object->convert('100030.46'), '壹拾万零叁拾元肆角陆分', '100030.46 is 壹拾万零叁拾元肆角陆分');
is($object->convert('13030700809'), '壹佰叁拾亿零叁仟零柒拾万零捌佰零玖元整', '13030700809 is 壹佰叁拾亿零叁仟零柒拾万零捌佰零玖元整');
is($object->convert('1200000000000000'), '壹仟贰佰万亿元整', '1200000000000000 is 壹仟贰佰万亿元整');
