#########################

use Test::More "no_plan";

#########################

use Money::Chinese;

my $object = Money::Chinese->new;

is($object->convert('1		11,103		'), '壹拾壹万壹仟壹佰零叁元整', '111103 is 壹拾壹万壹仟壹佰零叁元整');
is($object->convert('  100, 0  30.46'), '壹拾万零叁拾元肆角陆分', '100030.46 is 壹拾万零叁拾元肆角陆分');
is($object->convert('13  ,030,700,809  '), '壹佰叁拾亿零叁仟零柒拾万零捌佰零玖元整', '13030700809 is 壹佰叁拾亿零叁仟零柒拾万零捌佰零玖元整');
